summaryrefslogtreecommitdiffstats
path: root/src/intel/vulkan/anv_private.h
diff options
context:
space:
mode:
authorJason Ekstrand <jason.ekstrand@intel.com>2016-05-13 12:50:11 -0700
committerJason Ekstrand <jason.ekstrand@intel.com>2016-05-17 12:17:22 -0700
commit234ecf26c65a8909e91313a8b35e2a8a8bbfc0ef (patch)
tree95ec965887390be3537d0a74adff7f99a8df573c /src/intel/vulkan/anv_private.h
parent1bda8d06e54ee56db89a00e7a9ed8577d724fc9f (diff)
downloadexternal_mesa3d-234ecf26c65a8909e91313a8b35e2a8a8bbfc0ef.zip
external_mesa3d-234ecf26c65a8909e91313a8b35e2a8a8bbfc0ef.tar.gz
external_mesa3d-234ecf26c65a8909e91313a8b35e2a8a8bbfc0ef.tar.bz2
anv/image: Add an aspects field
This makes several checks easier and allows us to avoid calling anv_format_for_vk_format in a number of cases.
Diffstat (limited to 'src/intel/vulkan/anv_private.h')
-rw-r--r--src/intel/vulkan/anv_private.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/intel/vulkan/anv_private.h b/src/intel/vulkan/anv_private.h
index a5888d6..c3b31e6 100644
--- a/src/intel/vulkan/anv_private.h
+++ b/src/intel/vulkan/anv_private.h
@@ -1561,6 +1561,7 @@ struct anv_image {
*/
VkFormat vk_format;
const struct anv_format *format;
+ VkImageAspectFlags aspects;
VkExtent3D extent;
uint32_t levels;
uint32_t array_size;
@@ -1579,7 +1580,7 @@ struct anv_image {
* Image subsurfaces
*
* For each foo, anv_image::foo_surface is valid if and only if
* anv_image::format has a foo aspect.
*
* The hardware requires that the depth buffer and stencil buffer be
* separate surfaces. From Vulkan's perspective, though, depth and stencil
@@ -1579,7 +1580,7 @@ struct anv_image {
*
* For each foo, anv_image::foo_surface is valid if and only if
- * anv_image::format has a foo aspect.
+ * anv_image::aspects has a foo aspect.
*
* The hardware requires that the depth buffer and stencil buffer be